==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_9/jsd_b0aa8e79d21f5e579908825e70aaccf6.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center WirelessControllerProvisionV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""



import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorB0Aa8E79D21F5E579908825E70Aaccf6(object):
    """WirelessControllerProvisionV1 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB0Aa8E79D21F5E579908825E70Aaccf6, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "apAuthorizationListName": {
                "type": "string"
                },
                "authorizeMeshAndNonMeshAccessPoints": {
                "type": "boolean"
                },
                "interfaces": {
                "items": {
                "properties": {
                "interfaceGateway": {
                "type": "string"
                },
                "interfaceIPAddress": {
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "interfaceNetmaskInCIDR": {
                "type": "integer"
                },
                "lagOrPortNumber": {
                "type": "integer"
                },
                "vlanId": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "rollingApUpgrade": {
                "properties": {
                "apRebootPercentage": {
                "type": "integer"
                },
                "enableRollingApUpgrade": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "skipApProvision": {
                "type": "boolean"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_9/jsd_b0aa8e79d21f5e579908825e70aaccf6.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center WirelessControllerProvisionV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorB0Aa8E79D21F5E579908825E70Aaccf6(object):
    """WirelessControllerProvisionV1 request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorB0Aa8E79D21F5E579908825E70Aaccf6, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "apAuthorizationListName": {
                "type": "string"
                },
                "authorizeMeshAndNonMeshAccessPoints": {
                "type": "boolean"
                },
                "interfaces": {
                "items": {
                "properties": {
                "interfaceGateway": {
                "type": "string"
                },
                "interfaceIPAddress": {
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "interfaceNetmaskInCIDR": {
                "type": "integer"
                },
                "lagOrPortNumber": {
                "type": "integer"
                },
                "vlanId": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "rollingApUpgrade": {
                "properties": {
                "apRebootPercentage": {
                "type": "integer"
                },
                "enableRollingApUpgrade": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "skipApProvision": {
                "type": "boolean"
                }
                },
                "type": "object"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
